#
# spec file for package python-jaraco.itertools
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-jaraco.itertools
Version:        6.4.1
Release:        2.1
Summary:        Tools to work with iterables
License:        MIT
URL:            https://github.com/jaraco/jaraco.itertools
Source0:        https://files.pythonhosted.org/packages/source/j/jaraco.itertools/jaraco.itertools-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.8}
BuildRequires:  %{python_module inflect}
BuildRequires:  %{python_module more-itertools >= 4.0.0}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools >= 56}
BuildRequires:  %{python_module setuptools_scm >= 3.4.1}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-inflect
Requires:       python-more-itertools >= 4.0.0
BuildArch:      noarch
%python_subpackages

%description
jaraco.itertools Tools for working with iterables.
Complements itertools and more_itertools.

%prep
%setup -q -n jaraco.itertools-%{version}
rm -r jaraco.itertools.egg-info

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest --doctest-modules

%files %{python_files}
%license LICENSE
%doc docs/*.rst README.rst NEWS.rst
%dir %{python_sitelib}/jaraco
%{python_sitelib}/jaraco[_.]itertools-%{version}.dist-info
%{python_sitelib}/jaraco/itertools.py*
%pycache_only %dir %{python_sitelib}/jaraco/__pycache__
%pycache_only %{python_sitelib}/jaraco/__pycache__/itertools*.py*

%changelog
* Tue Apr  1 2025 Markéta Machová <mmachova@suse.com>
- Make it compatible with older setuptools
* Wed Mar 26 2025 Steve Kowalik <steven.kowalik@suse.com>
- Normalize metadata directory name.
* Mon Nov 20 2023 Steve Kowalik <steven.kowalik@suse.com>
- Upate to 6.4.1:
  * Remove use of ``OrderedDict`` in ``partition_dict``.
  * Added ``summarize``.
  * Require Python 3.8 or later.
  * Added ``find_subseq``.
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Mon Aug 29 2022 Ben Greiner <code@bnavigator.de>
- Update to 6.2.1:
  [#15]: Fixed broken test in ensure_unique.
- v6.2.0: Added accumulate function.
- v6.1.1: Fixed typo in ensure_unique doctest.
- v6.1.0: Add ensure_unique function.
- v6.0.3: #13: Fixed doc build errors.
- v6.0.2: Minor fixes.
- v6.0.1: Switch to PEP 420 for namespace package.
- v6.0.0: Remove Counter.GetCount. Remove flatten and iflatten.
- Switch to PEP517 and remove obsolete jaraco.base requirement
* Mon Nov  8 2021 Dirk Müller <dmueller@suse.com>
- add six dependency for testsuite
* Mon Mar  9 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 5.0.0
  * infinite_call is superseded by more_itertools.repeatfunc
  * Require Python 3.6 or later.
* Fri Apr  5 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 4.4.2:
  * Fixed RuntimeError in takewhile_peek on later Pythons where StopIteration is no longer allowed in a generator.
* Tue Feb 26 2019 John Vandenberg <jayvdb@gmail.com>
- Remove bcond_with test, allowing tests suite to run
- Add LICENSE
- Compile manually due to switch to pkgutil namespace technique
- Set minimum version more-itertools >= 4.0.0
- Update to v4.4.1
  * Fixed issue in ``collate_revs`` when objects being merged were non-True
- from 4.4
  * Add ``collate_revs`` and ``partition_dict``
- from 4.3
  * Nicer error message in ``assert_ordered`` when the assertion fails.
    Now reports the full supplied items and not just the keys in the errors.
    When ``<`` or ``>`` are used, the error message renders more directly.
- from 4.2
  * The ``duplicates`` function now takes an arbitrary number of iterables
  * Added ``assert_ordered`` function
- from 4.1
  * Added ``duplicates`` function
- from 4.0.0
  * Switch to pkgutil namespace technique for the ``jaraco`` namespace
- from 3.0.0
  * Refreshed project metadata, now built using declarative config.
    Installation from sdist now requires setuptools 34.4.
- from 2.5.2
  * Fix deprecation warning in ``always_iterable``
  * Leverage base_type parameter in ``more_itertools.always_iterable``
- from 2.5.1
  * Set stacklevel in deprecated functions for better visibility of the call.
- from 2.5
  * Added new ``maybe_single`` function
  * Deprecated ``list_or_iterable`` in favor of ``maybe_single``
- from 2.4
  * Deprecated ``flatten`` and ``iflatten`` in favor of
    ``more_itertools.collapse``. Deprecated ``iterable_test``,
    only used by deprecated functions.
  * Bump dependency on more_itertools 4.0.0.
- from 2.3
  * Added ``self_product``.
- from 2.2
  * ``first`` now accepts a default value, same as ``next``.
* Mon Nov 13 2017 toddrme2178@gmail.com
- Properly handle namespace package structure.
  This guarantees the module is importable.
* Tue Jul  4 2017 aloisio@gmx.com
- Update to version 2.0.1
  * Refresh package.
  2.0:
  * In ``always_iterable``, mappings are now considered
    singletons. It seems that the way ``always_iterable``
    is generally used, one wouldn't expect to only iterate
    on a mapping, but there are cases where a dictionary
    should behave like a singleton object.
  1.8:
  * Deprecated ``infiniteCall`` and replaced it with
    ``infinite_call`` which only takes a single argument
    (the function to call).
- Converted to single-spec
* Tue Aug  2 2016 sor.alexei@meowr.ru
- Switch to Python2.
* Thu Jun  9 2016 toddrme2178@gmail.com
- Remove unneeded python3-Sphinx dependency.
* Sun May  8 2016 arun@gmx.de
- specfile:
  * updated source url to files.pythonhosted.org
* Tue Dec 29 2015 arun@gmx.de
- specfile:
  * replace hgtools with setuptools_scm
  * update requiremenst according to setup.py
  * .txt -> *.rst in %%doc
- update to version 1.7.1:
  * Fix failing tests on Python 2.
* Sun Nov 22 2015 arun@gmx.de
- specfile:
  * fix typo in setup.py via sed command
- update to version 1.7:
  * Moved hosting to github.
- changes from version 1.6:
  * Releases now include wheels.
* Mon Nov  2 2015 toddrme2178@gmail.com
- Fix conflicts with other jaraco packages.
* Mon Nov  2 2015 toddrme2178@gmail.com
- Enable unit tests.
* Mon Nov  2 2015 toddrme2178@gmail.com
- Fix spec file name.
* Thu Oct 29 2015 arun@gmx.de
- update to version 1.5.1:
  * Peekable also accepts an iterable.
  * Fix test failure on Python 2
  * Added some doctests for bisect and corrected docstring to match
    implementation.
- change from version 1.5.0:
  * Add takewhile_peek function.
* Sat Aug  1 2015 arun@gmx.de
- specfile:
  * moved from zip to tar.gz
- update to version 1.4:
  * Add list_or_single function.
* Sun Mar  8 2015 arun@gmx.de
- update to version 1.3:
  * Add apply to apply a function to an iterable, but yield the original items.
* Sun Feb 22 2015 arun@gmx.de
- update to version 1.2:
  * Make pytest_runner and sphinx optionally required.
* Sat Feb 14 2015 arun@gmx.de
- initial version
